.. image:: https://readthedocs.org/projects/nano-utils/badge/?version=latest
    :target: https://Nano-Utils.readthedocs.io/en/latest/includeme.html
.. image:: https://badge.fury.io/py/Nano-Utils.svg
    :target: https://badge.fury.io/py/Nano-Utils
.. image:: https://github.com/nlesc-nano/Nano-Utils/workflows/Build/badge.svg
    :target: https://github.com/nlesc-nano/Nano-Utils/actions?query=workflow%3ABuild
.. image:: https://codecov.io/gh/nlesc-nano/Nano-Utils/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/nlesc-nano/Nano-Utils
.. image:: https://zenodo.org/badge/268804056.svg
   :target: https://zenodo.org/badge/latestdoi/268804056

|

.. image:: https://img.shields.io/badge/python-3.7-blue.svg
    :target: https://docs.python.org/3.7/
.. image:: https://img.shields.io/badge/python-3.8-blue.svg
    :target: https://docs.python.org/3.8/
.. image:: https://img.shields.io/badge/python-3.9-blue.svg
    :target: https://docs.python.org/3.9/
.. image:: https://img.shields.io/badge/python-3.10-blue.svg
    :target: https://docs.python.org/3.10/


################
Nano-Utils 2.2.0
################
Utility functions used throughout the various nlesc-nano repositories.


Installation
************
* PyPi: ``pip install Nano-Utils``
* GitHub: ``pip install git+https://github.com/nlesc-nano/Nano-Utils@master``
